﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using GalaSoft.MvvmLight;
using System.Windows.Input;
using GalaSoft.MvvmLight.Command;
using System.Windows;
using Infragistics.Persistence;
using System.IO;

namespace WpfApplication36
{
    public class MainWindowViewModel : ViewModelBase
    {

        public MainWindowViewModel()
        {
            SaveSettingsCommand = new RelayCommand<DependencyObject>((p) =>
            {
                SaveSettings(p);
            });

            LoadSettingsCommand = new RelayCommand<DependencyObject>((p) =>
            {
                LoadSettings(p);
            });
        }
        public ICommand SaveSettingsCommand { get; set; }
        public ICommand LoadSettingsCommand { get; set; }

        public static byte[] GetSavedSettings(DependencyObject obj)
        {
            return (byte[])obj.GetValue(SavedSettingsProperty);
        }

        public static void SetSavedSettings(DependencyObject obj, byte[] value)
        {
            obj.SetValue(SavedSettingsProperty, value);
        }

        // Using a DependencyProperty as the backing store for SavedSettings. 
        public static readonly DependencyProperty SavedSettingsProperty =
            DependencyProperty.RegisterAttached("SavedSettings", typeof(byte[]), typeof(DependencyObject), new PropertyMetadata(null));

        Dictionary<Type, byte[]> initialSettings = new Dictionary<Type, byte[]>();

        public byte[] SaveSettings(object item)
        {
            DependencyObject obj = item as DependencyObject;
            if (obj != null)
            {
                using (MemoryStream ms = Infragistics.Persistence.PersistenceManager.Save(item as DependencyObject))
                {
                    SetSavedSettings(obj, ms.ToArray());
                    return GetSavedSettings(obj);
                }
            }
            return null;
        }

        public void InitializeSettings(object item)
        {
            if (!initialSettings.ContainsKey(item.GetType()))
                initialSettings.Add(item.GetType(), SaveSettings(item));
        }

        public void LoadSettings(object item)
        {
            DependencyObject obj = item as DependencyObject;
            var settings = GetSavedSettings(obj);
            if (settings != null)
                using (MemoryStream ms = new MemoryStream(settings))
                {
                    PersistenceManager.Load(obj, ms);
                }
        }

    }
}
